@@ -107,47 +107,50 @@ def log_model(pytorch_model, artifact_path, conda_env=None, code_paths=None,
                                   registered model if one with the given name does not exist.
     :param kwargs: kwargs to pass to ``torch.save`` method.
 
-    >>> import torch
-    >>> import mlflow
-    >>> import mlflow.pytorch
-    >>> # X data
-    >>> x_data = torch.Tensor([[1.0], [2.0], [3.0]])
-    >>> # Y data with its expected value: labels
-    >>> y_data = torch.Tensor([[2.0], [4.0], [6.0]])
-    >>> # Partial Model example modified from Sung Kim
-    >>> # https://github.com/hunkim/PyTorchZeroToAll
-    >>> class Model(torch.nn.Module):
-    >>>    def __init__(self):
-    >>>       super(Model, self).__init__()
-    >>>       self.linear = torch.nn.Linear(1, 1)  # One in and one out
-    >>>    def forward(self, x):
-    >>>        y_pred = self.linear(x)
-    >>>        return y_pred
-    >>> # our model
-    >>> model = Model()
-    >>> criterion = torch.nn.MSELoss(size_average=False)
-    >>> optimizer = torch.optim.SGD(model.parameters(), lr=0.01)
-    >>> # Training loop
-    >>> for epoch in range(500):
-    >>>    # Forward pass: Compute predicted y by passing x to the model
-    >>>    y_pred = model(x_data)
-    >>>    # Compute and print loss
-    >>>    loss = criterion(y_pred, y_data)
-    >>>    print(epoch, loss.data.item())
-    >>>    #Zero gradients, perform a backward pass, and update the weights.
-    >>>    optimizer.zero_grad()
-    >>>    loss.backward()
-    >>>    optimizer.step()
-    >>>
-    >>> # After training
-    >>> for hv in [4.0, 5.0, 6.0]:
-    >>>     hour_var = torch.Tensor([[hv]])
-    >>>     y_pred = model(hour_var)
-    >>>     print("predict (after training)",  hv, model(hour_var).data[0][0])
-    >>> # log the model
-    >>> with mlflow.start_run() as run:
-    >>>   mlflow.log_param("epochs", 500)
-    >>>   mlflow.pytorch.log_model(model, "models")
+    .. code-block:: python
+        :caption: Example
+
+        import torch
+        import mlflow
+        import mlflow.pytorch
+        # X data
+        x_data = torch.Tensor([[1.0], [2.0], [3.0]])
+        # Y data with its expected value: labels
+        y_data = torch.Tensor([[2.0], [4.0], [6.0]])
+        # Partial Model example modified from Sung Kim
+        # https://github.com/hunkim/PyTorchZeroToAll
+        class Model(torch.nn.Module):
+            def __init__(self):
+               super(Model, self).__init__()
+               self.linear = torch.nn.Linear(1, 1)  # One in and one out
+            def forward(self, x):
+                y_pred = self.linear(x)
+            return y_pred
+        # our model
+        model = Model()
+        criterion = torch.nn.MSELoss(size_average=False)
+        optimizer = torch.optim.SGD(model.parameters(), lr=0.01)
+        # Training loop
+        for epoch in range(500):
+            # Forward pass: Compute predicted y by passing x to the model
+            y_pred = model(x_data)
+            # Compute and print loss
+            loss = criterion(y_pred, y_data)
+            print(epoch, loss.data.item())
+            #Zero gradients, perform a backward pass, and update the weights.
+            optimizer.zero_grad()
+            loss.backward()
+            optimizer.step()
+
+        # After training
+        for hv in [4.0, 5.0, 6.0]:
+            hour_var = torch.Tensor([[hv]])
+            y_pred = model(hour_var)
+            print("predict (after training)",  hv, model(hour_var).data[0][0])
+        # log the model
+        with mlflow.start_run() as run:
+            mlflow.log_param("epochs", 500)
+            mlflow.pytorch.log_model(model, "models")
     """
     pickle_module = pickle_module or mlflow_pytorch_pickle_module
     Model.log(artifact_path=artifact_path, flavor=mlflow.pytorch, pytorch_model=pytorch_model,
@@ -197,20 +200,23 @@ def save_model(pytorch_model, path, conda_env=None, mlflow_model=Model(), code_p
                           deserialize ("unpickle") the PyTorch model at load time.
     :param kwargs: kwargs to pass to ``torch.save`` method.
 
-    >>> import torch
-    >>> import mlflow
-    >>> import mlflow.pytorch
-    >>> # create model and set values
-    >>> pytorch_model = Model()
-    >>> pytorch_model_path = ...
-    >>> #train our model
-    >>> for epoch in range(500):
-    >>>     y_pred = model(x_data)
-    >>>     ...
-    >>> #save the model
-    >>> with mlflow.start_run() as run:
-    >>>   mlflow.log_param("epochs", 500)
-    >>>   mlflow.pytorch.save_model(pytorch_model, pytorch_model_path)
+    .. code-block:: python
+        :caption: Example
+
+        import torch
+        import mlflow
+        import mlflow.pytorch
+        # Create model and set values
+        pytorch_model = Model()
+        pytorch_model_path = ...
+        # train our model
+        for epoch in range(500):
+            y_pred = pytorch_model(x_data)
+            ...
+        # Save the model
+        with mlflow.start_run() as run:
+            mlflow.log_param("epochs", 500)
+            mlflow.pytorch.save_model(pytorch_model, pytorch_model_path)
     """
     import torch
     pickle_module = pickle_module or mlflow_pytorch_pickle_module
@@ -323,14 +329,17 @@ def load_model(model_uri, **kwargs):
     :param kwargs: kwargs to pass to ``torch.load`` method.
     :return: A PyTorch model.
 
-    >>> import torch
-    >>> import mlflow
-    >>> import mlflow.pytorch
-    >>> # set values
-    >>> model_path_dir = ...
-    >>> run_id="96771d893a5e46159d9f3b49bf9013e2"
-    >>> pytorch_model = mlflow.pytorch.load_model("runs:/" + run_id + "/" + model_path_dir)
-    >>> y_pred = pytorch_model(x_new_data)
+    .. code-block:: python
+        :caption: Example
+
+        import torch
+        import mlflow
+        import mlflow.pytorch
+        # Set values
+        model_path_dir = ...
+        run_id = "96771d893a5e46159d9f3b49bf9013e2"
+        pytorch_model = mlflow.pytorch.load_model("runs:/" + run_id + "/" + model_path_dir)
+        y_pred = pytorch_model(x_new_data)
     """
     import torch
 
